@@ -1,6 +1,6 @@
 # $Author: ddumont $
-# $Date: 2009-07-31 16:37:39 +0200 (Fri, 31 Jul 2009) $
-# $Revision: 1009 $
+# $Date: 2010-01-29 14:22:45 +0100 (Fri, 29 Jan 2010) $
+# $Revision: 1061 $
 
 #    Copyright (c) 2008-2009 Dominique Dumont.
 #
@@ -30,7 +30,7 @@ use Log::Log4perl;
 use base qw/Config::Model::Tk::LeafViewer/;
 use vars qw/$VERSION/ ;
 
-$VERSION = sprintf "1.%04d", q$Revision: 1009 $ =~ /(\d+)/;
+$VERSION = sprintf "1.%04d", q$Revision: 1061 $ =~ /(\d+)/;
 
 Construct Tk::Widget 'ConfigModelLeafEditor';
 
@@ -63,7 +63,7 @@ sub Populate {
 
     $cw->add_header(Edit => $leaf) ;
 
-    $cw->{value} = $leaf->fetch || '';
+    $cw->{value} = $leaf->fetch ;
     my $vref = \$cw->{value};
 
     my @pack_args = @fx ;
@@ -80,6 +80,8 @@ sub Populate {
 						-scrollbars => 'ow',
 					      )
                              ->pack(@fbe1);
+	$cw->{e_widget}
+	  ->tagConfigure(qw/value -lmargin1 2 -lmargin2 2 -rmargin 2/);
 	$cw->reset_value ;
 	my $bframe = $cw->add_buttons($ed_frame) ;
 	$bframe -> Button ( -text => 'Cleanup',
@@ -109,7 +111,9 @@ sub Populate {
 	my @choice = $leaf->get_choice ;
 	$lb->insert('end',$leaf->get_choice) ;
 	my $idx = 0;
-	map { $lb->selectionSet($idx) if $_ eq $$vref; $idx ++}  @choice;
+	if (defined $$vref) {
+	  map { $lb->selectionSet($idx) if $_ eq $$vref; $idx ++}  @choice;
+	}
 	$lb->bind('<Button-1>',sub {$cw->try($lb->get($lb->curselection()))});
 	$cw->add_buttons($ed_frame) ;
 
@@ -179,6 +183,8 @@ sub try {
 	$v = defined  $e_w ? $e_w->get('1.0','end')
            :                 $cw->{value} ;
     }
+
+    return unless defined $v;
     chomp $v ;
 
     $logger->debug( "try: value $v") ;
@@ -192,7 +198,7 @@ sub try {
 		      )
             -> Show ;
 	$cw->reset_value ;
-	return undef ;
+	return ;
     }
     else {
 	$cw->set_value_help($v) ;
@@ -256,7 +262,7 @@ sub reset_value {
     $cw->{value} = $cw->{leaf}->fetch ;
     if (defined $cw->{e_widget}) {
 	$cw->{e_widget}->delete('1.0','end') ;
-	$cw->{e_widget}->insert('end',$cw->{value}) ;
+	$cw->{e_widget}->insert('end',$cw->{value},'value') ;
     }
     $cw->set_value_help if defined $cw->{value_help_widget};
 }
